@@ -12,7 +12,7 @@ if not db_user:
 if not db_password:
     db_password = General.DEFAULT_PASSWORD
 
-if not db_password:
-    db_password = General.DEFAULT_HOST
+if not host:
+    host = General.DEFAULT_HOST
 
 conn = MySqlConnection(host=host, user=db_user, password=db_password, database=General.DATABASE)
