@@ -1,12 +1,12 @@
 import uvicorn
 from fastapi import FastAPI
 from api_utils.database import conn
-import router
+from router import entities
 
 app = FastAPI(title='Entities.ly',
               description='APIs for rr base entities Apis',
               version='0.1')
-app.include_router(router.entities.router_entities)
+app.include_router(entities.router_entities)
 
 
 def open_server(host: str = '127.0.0.1', port: int = 8000):
@@ -22,5 +22,3 @@ async def startup():
 async def shutdown():
     print("Closing db instance...")
     conn.close_connection()
-
-
