@@ -1,12 +1,12 @@
 import uvicorn
 from fastapi import FastAPI
 from api_utils.database import conn
-import router
+from router import players
 
 app = FastAPI(title='Data.ly',
               description='APIs for base rr data Apis',
               version='0.1')
-app.include_router(router.players.router_players)
+app.include_router(players.router_players)
 
 
 def open_server(host: str = '127.0.0.1', port: int = 8001):
@@ -22,4 +22,3 @@ async def startup():
 async def shutdown():
     print("Closing db instance...")
     conn.close_connection()
-
